#!/bin/sh
#
# Copyright © 2016 Collabora Ltd.
#
# SPDX-License-Identifier: MPL-2.0
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# ade-tests-custom.sh
#
# This test script will exercise some ade features in order to catch issues in what real users may try out:
# * listing installed sysroots
# * listing available sysroots
# * downloading sysroots
# * verifying sysroots
# * installing sysroots
# * targeting different distributions, releases and architectures
# * cross-building
# * exporting app-bundles
# * default and non-default parameters
#
# It needs:
# * network access to fetch sysroots for arm64 and armhf
# * network access to clone the sample-app source repository
# * the arm64 gcc-aarch64-linux-gnu cross-toolchain
# * the armhf gcc-arm-linux-gnueabi cross-toolchain

set -eux

checkCmd()
{
    $1;
    if [ $? != 0 ]; then
	echo "TEST_RESULT:fail:ade-tests-custom:$1"
	exit 1
    fi
}

. /etc/os-release # import $ID and $VERSION_ID

LANG=C.UTF-8
DISTRIBUTION=$ID
RELEASE=$VERSION_ID
OLDRELEASE=18.06
ARCH=arm64 # the non-default one to be tested
SYSROOTINDEX="https://images.apertis.org/sysroot/$OLDRELEASE/sysroot-$DISTRIBUTION-$OLDRELEASE-$ARCH"
SAMPLEAGENTREPO=https://gitlab.apertis.org/sample-applications/helloworld-simple-agent/

checkCmd "git clone $SAMPLEAGENTREPO sample-app"

checkCmd "ade sysroot list"

echo ==== Testing ade usage with custom parameters

checkCmd "ade sysroot installed --distro $DISTRIBUTION --release $OLDRELEASE --arch $ARCH"

checkCmd "ade sysroot latest --distro $DISTRIBUTION --release $OLDRELEASE --arch $ARCH"

checkCmd "ade sysroot latest --distro $DISTRIBUTION --release $OLDRELEASE --arch $ARCH --url "$SYSROOTINDEX""

checkCmd "ade sysroot download --distro $DISTRIBUTION --release $OLDRELEASE --arch $ARCH --url "$SYSROOTINDEX" --dest /opt/sysroot/downloads/"

checkCmd "ade sysroot verify --file /opt/sysroot/downloads/sysroot-$DISTRIBUTION-$OLDRELEASE-${ARCH}_*.tar.gz"

checkCmd "ade sysroot install --file /opt/sysroot/downloads/sysroot-$DISTRIBUTION-$OLDRELEASE-${ARCH}_*.tar.gz"

checkCmd "ade sysroot list"

checkCmd "cd sample-app"

checkCmd "ade configure --debug --sysroot $DISTRIBUTION-$OLDRELEASE-$ARCH"
checkCmd "ade export"

checkCmd "ls -l *.bundle"

checkCmd "git clean -fdx"

echo "TEST_RESULT:pass:ade-tests-custom:"
